@@ -5,12 +5,14 @@ import collections
 import inspect
 import subprocess
 
+import odoo_repl
+
 from odoo_repl import access
 from odoo_repl import color
 from odoo_repl import fields
 from odoo_repl import grep
 from odoo_repl import methods
-from odoo_repl import records
+from odoo_repl import search
 from odoo_repl import sources
 from odoo_repl import util
 from odoo_repl.imports import abc, odoo, t, cast, Field, PY3, Text, BaseModel
@@ -91,15 +93,7 @@ def model_repr(obj):
     by_module = collections.defaultdict(list)
     for field in field_names:
         f_obj = obj._fields[field]
-        rep = (
-            color.blue.bold(_fmt_properties(f_obj))
-            + " {}: ".format(color.field(field))
-            # Like str.ljust, but not confused about colors
-            + (max_len - len(field)) * " "
-            + color.color_field(f_obj)
-        )
-        if not fields.has_auto_string(f_obj):
-            rep += u" ({})".format(util.try_decode(f_obj.string))
+        rep = format_single_field(f_obj, max_len=max_len)
         f_module = sources.find_field_module(f_obj) or original_module
         by_module[f_module].append(rep)
 
@@ -142,6 +136,22 @@ def model_repr(obj):
     return "\n".join(parts)
 
 
+def format_single_field(field, max_len=None):
+    # type: (Field, t.Optional[int]) -> t.Text
+    if max_len is None:
+        max_len = len(field.name)
+    rep = (
+        color.blue.bold(_fmt_properties(field))
+        + " {}: ".format(color.field(field.name))
+        # Like str.ljust, but not confused about colors
+        + (max_len - len(field.name)) * " "
+        + color.color_field(field)
+    )
+    if not fields.has_auto_string(field):
+        rep += u" ({})".format(util.try_decode(field.string))
+    return rep
+
+
 def _fmt_properties(field):
     # type: (Field) -> t.Text
     parts = [" ", " ", " ", " "]
@@ -381,7 +391,7 @@ class ModelProxy(object):
         # type: (int) -> BaseModel
         """Return a random record, or multiple."""
         assert self._real is not None
-        return records.search_(self._real, shuf=num)
+        return search.search(self._real, (), {"shuf": num})
 
     def source_(self, location=None):
         # type: (t.Optional[t.Text]) -> None
@@ -460,7 +470,7 @@ class ModelProxy(object):
                 ),
                 pretty_print=True,
                 encoding="unicode",
-            )
+            ).replace("&#10;", "\n")
         print(color.highlight(form, "xml"))
 
     def sql_(self):
@@ -511,7 +521,7 @@ class ModelProxy(object):
             meths = [
                 (name, attr)
                 for name, attr in sorted(vars(cls).items())
-                if callable(attr)
+                if util.loosely_callable(attr)
                 if name != "pool"
             ]
             if meths:
@@ -610,10 +620,24 @@ class ModelProxy(object):
                 print_act(action, link=False)
                 print()
 
+    def print_(self, **kwargs):
+        # type: (t.Any) -> None
+        """Print all records. Shortcut for `._().print_()`."""
+        odoo_repl.odoo_print(self._(), **kwargs)
+
     def _(self, *args, **kwargs):
         # type: (t.Any, t.Any) -> t.Any
+        """Perform a quick and dirty search.
+
+        ._(x='test', y=<some record>) is roughly equivalent to
+        .search([('x', '=', 'test'), ('y', '=', <some record>.id)]).
+
+        ._(x__y__ne='test') is equivalent to .search([('x.y', '!=', 'test')]).
+
+        ._() gets all records.
+        """
         assert self._real is not None
-        return self._real.search_(*args, **kwargs)  # type: ignore
+        return search.search(self._real, args, kwargs)
 
 
 def _to_user(
